/*
 * Copyright (C) 2004 emuWorks
 * http://games.technoplaza.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
    #include <config.h>
#endif
 
#include <wx/wxprec.h>

#ifndef WX_PRECOMP
   #include <wx/wx.h>
#endif
 
#include "chtframe.hh"
#include "../chtdecoder.hh"
#include "../datastructures/chtcode.hh"

using namespace wxCHTDecoder;

BEGIN_EVENT_TABLE(CHTFrame, wxFrame)
    EVT_MENU(IDM_FILE_OPEN, CHTFrame::OnOpen)
    EVT_MENU(IDM_FILE_SAVE, CHTFrame::OnSave)
    EVT_MENU(IDM_FILE_EXIT, CHTFrame::OnExit)
    EVT_MENU(IDM_HELP_ABOUT, CHTFrame::OnAbout)
END_EVENT_TABLE()

CHTFrame::CHTFrame(const wxString& title, const wxPoint& pos,
                   const wxSize& size) : wxFrame(NULL, -1, title, pos, size) {
    // build the main menu
    menuBar = new wxMenuBar();
    fileMenu = new wxMenu();
    helpMenu = new wxMenu();
    
    fileMenu->Append(IDM_FILE_OPEN, 
                     wxT("&Open"), 
                     wxT("Open .CHT File for Decoding"));
    fileMenu->Append(IDM_FILE_SAVE, 
                     wxT("&Save"), 
                     wxT("Save decode .CHT codes to file"));
    fileMenu->AppendSeparator();
    fileMenu->Append(IDM_FILE_EXIT, 
                     wxT("E&xit"),
                     (wxT("Exit ") + *CHTDecoder::APP_NAME));
    
    // disable saving till one is loaded
    fileMenu->Enable(IDM_FILE_SAVE, false);
    
    helpMenu->Append(IDM_HELP_ABOUT, 
                     wxT("&About ") + *CHTDecoder::APP_NAME + wxT("..."),
                     wxT("Display Copyright Information"));
    
    menuBar->Append(fileMenu, wxT("&File"));
    menuBar->Append(helpMenu, wxT("&Help"));
    
    SetMenuBar(menuBar);
    
    // build the status bar
    CreateStatusBar();
    SetStatusText(*CHTDecoder::APP_NAME + wxT(' ') + *CHTDecoder::APP_VERSION);
    
    // build the text control
    chtText = new CHTTextControl(this);
}

void CHTFrame::OnOpen(wxCommandEvent& event) {
    static wxFileDialog *dlg = new wxFileDialog(this, 
        wxT("Choose a .CHT file to decode..."), "", "", 
        wxT("ZSNES .CHT Files (*.cht)|*.cht"), (wxOPEN | wxCHANGE_DIR));
    
    int value = dlg->ShowModal();
    
    if (value == wxID_OK) {
        wxString filename = dlg->GetPath();
        chtText->readCHTFile(filename);
    }
}

void CHTFrame::OnSave(wxCommandEvent& event) {
    static wxFileDialog *dlg = new wxFileDialog(this, 
        wxT("Choose a .TXT file to save to..."), "", "", 
        wxT("Text Files (*.txt)|*.txt"), (wxSAVE | wxCHANGE_DIR));
    
    int value = dlg->ShowModal();
    
    if (value == wxID_OK) {
        wxString filename = dlg->GetPath();
        chtText->SaveFile(filename);
    }
}

void CHTFrame::OnExit(wxCommandEvent& event) {
    Close(true);
}

void CHTFrame::OnAbout(wxCommandEvent &event) {
    wxMessageDialog dlg(this, *CHTDecoder::APP_NAME + wxT(' ') + 
                        *CHTDecoder::APP_VERSION + wxT('\n') +
                        *CHTDecoder::APP_COPYRIGHT, wxT("About ") + 
                        *CHTDecoder::APP_NAME + wxT("..."),
                        wxOK | wxICON_INFORMATION);
    dlg.ShowModal();
}

