/*
 * Copyright (C) 2004 emuWorks
 * http://games.technoplaza.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
    #include <config.h>
#endif
 
#include <vector>
 
#include "chttextcontrol.hh"
#include "chtfiledroptarget.hh"
#include "../tools/chtfilereader.hh"
#include "../exceptions/invalidchtfileexception.hh"

using namespace wxCHTDecoder;

const wxFont *CHTTextControl::MONOSPACED_FONT = new wxFont(12, wxMODERN, 
                                                           wxNORMAL, wxNORMAL);

CHTTextControl::CHTTextControl(CHTFrame *parent) :
    wxTextCtrl(parent, -1, wxEmptyString, wxDefaultPosition,
        wxDefaultSize, wxTE_MULTILINE | wxTE_READONLY | wxTE_RICH) {
    this->parent = parent;
    SetDropTarget(new CHTFileDropTarget(this));
}

bool CHTTextControl::readCHTFile(wxString &filename) {
    CHTFileReader &reader = CHTFileReader::getInstance();
        
    if (!CHTFileReader::isValidCHTFile(filename)) {
        wxMessageDialog dlg(this, wxT("Are you sure you want to open it?"), 
                            wxT("Potentially Invalid .CHT File..."),
                            (wxYES_NO | wxNO_DEFAULT | wxICON_QUESTION));
                                
        if (dlg.ShowModal() != wxID_YES) {
            return false;
        }
    }
    
    try {
        std::vector<CHTCode> &list = reader.readCHTFile(filename, true);
        wxString code;
            
        Clear();
        SetFont(*MONOSPACED_FONT);
            
        for (size_t i = 0; i < list.size(); i++) {
            code.Clear();
            code.Printf("%2d: %s\n", (i + 1), 
                        list[i].toString().mb_str());
            AppendText(code);
        }
                
        if (list.size() > 0) {
            parent->fileMenu->Enable(IDM_FILE_SAVE, true);
        }
    } catch (InvalidCHTFileException e) {
        return false;
    }
    
    return true;
}

